@@ -18,7 +18,7 @@ use Try::Tiny;
 use strict;
 use warnings;
 
-our $VERSION = '0.43';
+our $VERSION = '0.44';
 
 sub default_conf_names { ( 'tidyall.ini', '.tidyallrc' ) }
 
@@ -454,7 +454,7 @@ sub find_matched_files {
             @selected = grep { !$is_ignored{$_} } @selected;
         }
         if ( my $shebang = $plugin->shebang ) {
-            my $re = join '|', map {quotemeta} split ' ', $shebang;
+            my $re = join '|', map {quotemeta} @{$shebang};
             $re       = qr/^#!.*\b(?:$re)\b/;
             @selected = grep {
                 my $fh;
@@ -547,7 +547,7 @@ Code::TidyAll - Engine for tidyall, your all-in-one code tidier and validator
 
 =head1 VERSION
 
-version 0.43
+version 0.44
 
 =head1 SYNOPSIS
 
