@@ -9,7 +9,7 @@ use Text::Diff v1.44 qw( diff );
 
 use Moo;
 
-our $VERSION = '0.43';
+our $VERSION = '0.44';
 
 # External
 has 'argv'               => ( is => 'ro', default => q{} );
@@ -31,6 +31,27 @@ has 'ignores'      => ( is => 'lazy' );
 has 'select_regex' => ( is => 'lazy' );
 has 'selects'      => ( is => 'lazy' );
 
+around BUILDARGS => sub {
+    my $orig  = shift;
+    my $class = shift;
+
+    my $args = $class->$orig(@_);
+
+    # When the feature was first released it was documented as accepting a
+    # space separated list, and we want that to still work.
+    if ( defined $args->{shebang} && !ref $args->{shebang} ) {
+        $args->{shebang} = [ split /\s+/, $args->{shebang} ];
+    }
+
+    for my $key (qw( select ignore )) {
+        if ( defined $args->{$key} && !ref $args->{$key} ) {
+            $args->{$key} = [ $args->{$key} ];
+        }
+    }
+
+    return $args;
+};
+
 sub _build_cmd {
     die "no default cmd specified";
 }
@@ -97,13 +118,11 @@ sub validate_params {
 }
 
 sub _parse_zglob_list {
-    my ( $self, $zglob_list ) = @_;
-    $zglob_list = '' if !defined($zglob_list);
-    my @zglobs = split( /\s+/, $zglob_list );
-    if ( my ($bad_zglob) = ( grep {m{^/}} @zglobs ) ) {
+    my ( $self, $zglobs ) = @_;
+    if ( my ($bad_zglob) = ( grep {m{^/}} @{$zglobs} ) ) {
         die "zglob '$bad_zglob' should not begin with slash";
     }
-    return \@zglobs;
+    return $zglobs;
 }
 
 # No-ops by default; may be overridden in subclass
@@ -191,7 +210,7 @@ Code::TidyAll::Plugin - Create plugins for tidying or validating code
 
 =head1 VERSION
 
-version 0.43
+version 0.44
 
 =head1 SYNOPSIS
 
